@@ -78,21 +78,27 @@ class BaseLogin(object):
             return
 
         for command in commands:
-            try:
-                self.subprocess_utils.check_call(
-                    command,
-                    stdout=self.subprocess_utils.PIPE,
-                    stderr=self.subprocess_utils.PIPE,
-                )
-            except OSError as ex:
-                if ex.errno == errno.ENOENT:
-                    raise ValueError(
-                        self._TOOL_NOT_FOUND_MESSAGE % tool
-                    )
-                raise ex
+            self._run_command(tool, command)
 
         self._write_success_message(tool)
 
+    def _run_command(self, tool, command, *, ignore_errors=False):
+        try:
+            self.subprocess_utils.check_call(
+                command,
+                stdout=self.subprocess_utils.PIPE,
+                stderr=self.subprocess_utils.PIPE
+            )
+        except subprocess.CalledProcessError as ex:
+            if not ignore_errors:
+                raise ex
+        except OSError as ex:
+            if ex.errno == errno.ENOENT:
+                raise ValueError(
+                    self._TOOL_NOT_FOUND_MESSAGE % tool
+                )
+            raise ex
+
     @classmethod
     def get_commands(cls, endpoint, auth_token, **kwargs):
         raise NotImplementedError('get_commands()')
@@ -303,6 +309,10 @@ class NpmLogin(BaseLogin):
         )
         self._run_commands('npm', commands, dry_run)
 
+    def _run_command(self, tool, command):
+        ignore_errors = any('always-auth' in arg for arg in command)
+        super()._run_command(tool, command, ignore_errors=ignore_errors)
+
     @classmethod
     def get_scope(cls, namespace):
         # Regex for valid scope name
